==> hx_components_flutter-1.0.2.tar.gz: lib/src/widgets/hx_curved_appbar.dart <==
import 'package:flutter/material.dart';
import 'package:hx_components_flutter/hx_components.dart';
import 'package:hx_components_flutter/src/utils/appbar_login_customclipper.dart';
import 'package:hx_components_flutter/src/utils/appbar_menu_customclipper.dart';

class HxCurvedAppBar extends StatelessWidget {
  final bool isLogin;
  final Widget? versionWidget;

  const HxCurvedAppBar.login({
    super.key,
  })  : isLogin = true,
        versionWidget = null;

  const HxCurvedAppBar.menu({
    super.key,
    this.versionWidget,
  }) : isLogin = false;

  @override
  Widget build(BuildContext context) {
    return AppBar(
      backgroundColor: Colors.transparent,
      elevation: 0,
      flexibleSpace: Stack(
        children: [
          ClipPath(
            clipper: isLogin ? AppBarLoginCustomClipper() : AppBarMenuCustomClipper(),
            child: const HxAnimatedBg(),
          ),
          if (isLogin)
            Positioned(
              top: MediaQuery.of(context).viewPadding.top + 20,
              left: 40,
              child: Image.asset(
                'packages/hx_components_flutter/assets/images/logo.png',
                width: 200,
              ),
            )
          else
            Positioned(
              top: MediaQuery.of(context).viewPadding.top + 20,
              left: MediaQuery.of(context).size.width / 2 - 137 / 2,
              child: Center(
                child: Column(
                  children: [
                    Image.asset(
                      'packages/hx_components_flutter/assets/images/logo.png',
                      width: 137,
                    ),
                  ],
                ),
              ),
            ),
          if (!isLogin)
            Positioned(
              left: 20,
              bottom: 55,
              child: SizedBox(
                width: MediaQuery.of(context).size.width - 40,
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    Row(
                      children: [
                        const Icon(
                          Icons.account_circle,
                          color: Colors.white,
                        ),
                        const SizedBox(width: 4),
                        HxText.heading3(
                          'Roberto',
                          color: Colors.white,
                        ),
                      ],
                    ),
                    HxText(
                      'Terminal T15',
                      color: Colors.white,
                    ),
                  ],
                ),
              ),
            )
          else
            const SizedBox.shrink(),
        ],
      ),
    );
  }
}

==> hx_components_flutter-1.0.3.tar.gz: lib/src/widgets/hx_curved_appbar.dart <==
import 'package:flutter/material.dart';
import 'package:hx_components_flutter/hx_components.dart';
import 'package:hx_components_flutter/src/utils/appbar_login_customclipper.dart';
import 'package:hx_components_flutter/src/utils/appbar_menu_customclipper.dart';

class HxCurvedAppBar extends StatelessWidget {
  final bool isLogin;
  final Widget? versionWidget;
  final String? user;
  final String? terminal;

  const HxCurvedAppBar.login({
    super.key,
  })  : isLogin = true,
        versionWidget = null,
        user = null,
        terminal = null;

  const HxCurvedAppBar.menu({
    super.key,
    this.versionWidget,
    required this.user,
    required this.terminal,
  }) : isLogin = false;

  @override
  Widget build(BuildContext context) {
    return AppBar(
      backgroundColor: Colors.transparent,
      elevation: 0,
      flexibleSpace: Stack(
        children: [
          ClipPath(
            clipper: isLogin ? AppBarLoginCustomClipper() : AppBarMenuCustomClipper(),
            child: const HxAnimatedBg(),
          ),
          if (isLogin)
            Positioned(
              top: MediaQuery.of(context).viewPadding.top + 20,
              left: 40,
              child: Image.asset(
                'packages/hx_components_flutter/assets/images/logo.png',
                width: 200,
              ),
            )
          else
            Positioned(
              top: MediaQuery.of(context).viewPadding.top + 20,
              left: MediaQuery.of(context).size.width / 2 - 137 / 2,
              child: Center(
                child: Column(
                  children: [
                    Image.asset(
                      'packages/hx_components_flutter/assets/images/logo.png',
                      width: 137,
                    ),
                  ],
                ),
              ),
            ),
          if (!isLogin)
            Positioned(
              left: 20,
              bottom: 55,
              child: SizedBox(
                width: MediaQuery.of(context).size.width - 40,
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    Row(
                      children: [
                        const Icon(
                          Icons.account_circle,
                          color: Colors.white,
                        ),
                        const SizedBox(width: 4),
                        HxText.heading3(
                          user ?? '',
                          color: Colors.white,
                        ),
                      ],
                    ),
                    HxText(
                      'Terminal ${user ?? ''}',
                      color: Colors.white,
                    ),
                  ],
                ),
              ),
            )
          else
            const SizedBox.shrink(),
        ],
      ),
    );
  }
}
